import { setupDevtoolsPlugin } from '@vue/devtools-api';
import { App } from 'vue';
import { Store } from 'vuex';

const stateType = 'store';
// const inspectorId = 'vuex-z-plugin';

declare global {
  const __VUE_PROD_DEVTOOLS__: boolean;
}

interface PluginOptions {
  store: Store<any>;
}
export function setupDevtools(app: App, { store }: PluginOptions) {
  setupDevtoolsPlugin(
    {
      id: '@yzcode/vue-devtool-vuex-z',
      label: 'vue-devtool-vuex',
      packageName: '@yzcode/vue-devtool-vuex-z',
      homepage: 'my home',
      app,
      componentStateTypes: [stateType],
    },
    (api) => {
      // api.addInspector({
      //   id: inspectorId,
      //   label: 'vuex',
      //   icon: 'pets',
      // });

      store.subscribe((mutation, state) => {
        console.log('通知')
        api.notifyComponentUpdate();
      });
      
      api.on.inspectComponent((payload, context) => {
        payload.instanceData.state.push({
          type: stateType,
          key: 'state',
          value: store.state,
        });

        payload.instanceData.state.push({
          type: stateType,
          key: 'gettters',
          value: store.getters,
        });
      });
    }
  );
}

export default {
  install(app: App, options: PluginOptions) {
    // Our Vue plugin logic
    if (process.env.NODE_ENV === 'development' || __VUE_PROD_DEVTOOLS__) {
      setupDevtools(app, options);
    }
  },
};
